Error handling API

Use the error handling API to gather information contained in the
LoadLeveler error object and output that information as an error
message.

This API consists of the llr_error subroutine.


llr_error subroutine

Use the llr_error subroutine to convert an error object to an error
message string and free the memory associated with the error object. As
an option, the error message can be returned as string, printed to
stdout or stderr, or the memory can be free without printing or
returning a string.

Library

LoadLeveler API library libllrapi.a (AIX) or libllrapi.so (Linux)

Syntax


char *llr_error (llr_element_t ** errObj, llr_error_opt_t option)

Parameters

errObj
   Is the address of a pointer to a LoadLeveler error object that was
   returned by one of the resource manager API subroutines.

option
   Is an enum specifying the disposition of the error data. Possible
   values are: 

   LLR_ERROR_FREE
            The error object is freed.

   LLR_ERROR_PRINT_STDERR
            The error string is written to stderr and the error object
            is freed.

   LLR_ERROR_PRINT_STDOUT
            The error string is written to stdout and the error object
            is freed.

   LLR_ERROR_RETURN_STRING
            A copy of the error string is returned to the caller and the
            error object is freed. The caller is responsible for freeing
            the returned error string.


Description

It is the caller's responsibility to free the storage associated with
the error message string.

The LoadLeveler error object pointed to by *errObj is deleted upon exit
and NULL is assigned to *errObj.


Return Values

!NULL    A pointer to a character string containing the error message if
         the LLR_ERROR_RETURN_STRING option was specified. The error
         object has been freed. The caller is responsible for freeing
         the returned string.

NULL     The error object has been freed.
