/*
 * ------------------------------------------------------------------------
 * Sample program using llr_move_spool to move jobs from a old spool
 * -------------------------------------------------------------------------
 */
static char llrmovespool_sccsid[] = "@(#) src/ll/samples/llrmovespool/llrmovespool.c, ll.api, ll_rrur2, rrur21042a 1.2 3/17/10 03:45:26";

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "llrapi.h" 

int (*func) (char *jobid, int rc, llr_element_t **messageObj) = NULL;

int cb(char *jobid, int rc, llr_element_t **messageObj) {
	llr_element_t *errObj = NULL;
	printf("Begin to call the callback func:\n");
	printf("jobid = %s, rc = %d\n", jobid, rc);
	llr_error (&errObj, LLR_ERROR_PRINT_STDOUT);
	printf("Finish doing the callback func!\n");

	return 0;
}

int main(int argc, char * argv[]) {
	int llr_version = LLR_API_VERSION;
	llr_resmgr_handle_t *rm_handle = NULL;
	llr_element_t *errObj = NULL;
	int rc = -1;
	llr_move_spool_param_t *param_list[2];
	llr_move_spool_param_t param;

	if (argc < 3) {
		fprintf(stderr, "Usage: %s <receiving job manager> <old spool directory>\n", argv[0]);	
		return rc;
	}

	func = cb;
  
	param.schedd_host = (char **)malloc(2 * sizeof(char *)); 
	param.schedd_host[0] = argv[1];
	param.schedd_host[1] = NULL;
	param.spool_directory = argv[2];
	param.data = LLR_MOVE_SPOOL_JOBS;
	param_list[0] = &param;
	param_list[1] = NULL;

	rc = llr_init_resmgr(llr_version, &rm_handle, &errObj);
	if(rc != LLR_API_OK) {
		llr_error (&errObj, LLR_ERROR_PRINT_STDERR);
		return rc;
	}
	printf("llr_init_resmgr completed successfully\n");

	rc = llr_move_spool(rm_handle, param_list, func, &errObj);
	if(rc != LLR_API_OK) {
		llr_error (&errObj, LLR_ERROR_PRINT_STDERR);
		return rc;
	}
	printf("llr_move_spool completed successfully\n");
	llr_error (&errObj, LLR_ERROR_PRINT_STDOUT);
	errObj = NULL;

	rc = llr_free_resmgr(&rm_handle, &errObj);
	if(rc != LLR_API_OK) {
		llr_error (&errObj, LLR_ERROR_PRINT_STDERR);
		return rc;
	}
	printf("llr_free_resmgr completed successfully\n");

	return 0;
}
