/*
 * ------------------------------------------------------------------------
 * Query the resource manager to find the jobs and steps
 * -------------------------------------------------------------------------
 */
static char llrq_sccsid[] = "@(#) src/ll/samples/llrq/llrq.c, ll.api, ll_rrur2, rrur21042a 1.2 3/17/10 03:45:35";

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <string.h>
#include <errno.h>
#include <stdint.h> // for uint64_t
#include "llrapi.h"

const char* step_state_string(llr_step_state_t s) {
        switch(s) {
        case LLR_STATE_CANCELED:         return "STATE_CANCELED";
        case LLR_STATE_COMPLETED:        return "STATE_COMPLETED";
        case LLR_STATE_COMPLETE_PENDING: return "STATE_COMPLETE_PENDING";
        case LLR_STATE_DEFERRED:         return "STATE_DEFERRED";
        case LLR_STATE_HOLD:             return "STATE_HOLD";
        case LLR_STATE_IDLE:             return "STATE_IDLE";
        case LLR_STATE_NOTQUEUED:        return "STATE_NOTQUEUED";
        case LLR_STATE_NOTRUN:           return "STATE_NOTRUN";
        case LLR_STATE_PENDING:          return "STATE_PENDING";
        case LLR_STATE_PREEMPTED:        return "STATE_PREEMPTED";
        case LLR_STATE_PREEMPT_PENDING:  return "STATE_PREEMPT_PENDING";
        case LLR_STATE_REJECTED:         return "STATE_REJECTED";
        case LLR_STATE_REJECT_PENDING:   return "STATE_REJECT_PENDING";
        case LLR_STATE_REMOVED:          return "STATE_REMOVED";
        case LLR_STATE_REMOVE_PENDING:   return "STATE_REMOVE_PENDING";
        case LLR_STATE_RESUME_PENDING:   return "STATE_RESUME_PENDING";
        case LLR_STATE_RUNNING:          return "STATE_RUNNING";
        case LLR_STATE_STARTING:         return "STATE_STARTING";
        case LLR_STATE_SUBMISSION_ERR:   return "STATE_SUBMISSION_ERR";
        case LLR_STATE_TERMINATED:       return "STATE_TERMINATED";
        case LLR_STATE_UNEXPANDED:       return "STATE_UNEXPANDED";
        case LLR_STATE_VACATED:          return "STATE_VACATED";
        case LLR_STATE_VACATE_PENDING:   return "STATE_VACATE_PENDING";
        default:                         return "UNKNOWN_STATE";
        }
}
main(int argc, char *argv[]) {

	llr_resmgr_handle_t *rm_handle;
	llr_query_handle_t *q_handle = NULL;
	llr_element_t *err_object;
	llr_element_t **object_list;
	llr_element_t *job = NULL;
	llr_job_info_t job_info;
	llr_data_list_t step_list;
	void* step = NULL;
	char *job_id;
	char *step_id;
	int rc;
	int i;
	int step_count;
	char *job_string;
	llr_step_state_t step_state;
	

	err_object = NULL;
	rc = llr_init_resmgr(LLR_API_VERSION, &rm_handle, &err_object);
	if (rc != LLR_API_OK) {
		fprintf(stderr, "Resource manager API can not be intialized.\n");
		if (err_object) {
			llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
		}
		exit(-1);
	}

	rc = llr_query_set(rm_handle, &q_handle, LLR_JOBS_QUERY, 0, NULL, &err_object);
	if (rc != LLR_API_OK) {
		fprintf(stderr, "Failed to set up job query.\n");
		if (err_object) {
			llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
		}
		exit(-1);
	} 

	rc =  llr_query_get_data(rm_handle, q_handle, LLR_QUERY_RESOURCE_MANAGER, NULL, &object_list, &err_object);
	if (rc != LLR_API_OK) {
		if (err_object) {
			llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
		}
		fprintf(stderr, "llr_query_get_data failed.\n");
		exit(-1);
	}

	for (i=0; (job = object_list[i]) != NULL; i++) {
		rc = llr_get_data(rm_handle, job, LLR_JobID, &job_id, &err_object);
		if (rc == LLR_API_OK) {
			rc += llr_get_data(rm_handle, job, LLR_JobStepCount, &step_count, &err_object);
			fprintf(stdout, "Job %s has %d %s.\n", job_id, step_count, step_count==1?"step":"steps");
			rc += llr_get_data(rm_handle, job, LLR_JobGetStepList, &step_list, &err_object);
			rc += llr_get_data(rm_handle, &step_list, LLR_JobGetFirstStep, &step, &err_object);
			while (step != NULL) {
				rc += llr_get_data(rm_handle, step, LLR_StepID, &step_id, &err_object);
				rc += llr_get_data(rm_handle, step, LLR_StepState, &step_state, &err_object);
				fprintf(stdout, " Step %s is in %s.\n", step_id, step_state_string(step_state));
				rc += llr_get_data(rm_handle, &step_list, LLR_JobGetNextStep, &step, &err_object);
			}
			err_object = NULL;
		}
		if (rc != LLR_API_OK) {
			if (err_object) {
				llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
			}
			fprintf(stderr, "llr_get_data failed.\n");
			exit(-1);
		}
	}
	rc =  llr_query_free_data(rm_handle, &q_handle, &err_object);
	llr_free_resmgr(&rm_handle, &err_object);
}

