/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdint.h>
#include <vector>
#include "llrapi.h"
#include "Object.h"
#include "Mutex.h"

#ifndef Adapter_h
#define Adapter_h

class Adapter : public Object {
public:
	Adapter(const char* adapter_name, bool managed=false);
	~Adapter();

	Adapter* getManagedAdapter(const char* adapter_name);
	void clear_managed_adapters();

	bool updateData(void* llr_adapter, llr_event_type_t event_type);
	void display_adapter_data();

	/** SCHEDULER RESOURCE BOOKKEEPING **/
	void windowsInUse(int windows_in_use) {
		_windows_in_use = windows_in_use;
	}

	int windowsInUse() const {
		return _windows_in_use;
	}

	void exclusiveUse(int exclusive_use) {
		_exclusive_use = exclusive_use;
	}

	int exclusiveUse() const {
		return _exclusive_use;
	}
	/************************************/

	/* Adapter object data */
	char*    Name;                       
	char*    InterfaceAddress;       /* interface IP address */
	char*    InterfaceNetmask;       /* Netmask of adapter */
	uint64_t MinWindowSize64;        /* min allocatable window memory */
	uint64_t MaxWindowSize64;        /* max allocatable window memory */
	uint64_t Memory64;               /* Total adapter memory */
	int      TotalWindowCount;       /* # of windows on adapter */
	int      MCMId;                  /* mcm this adpter connected to */
	int      PortNumber;             /* Port number of adapter */
	int      Lmc;                    /* lmc of adapter */
	uint64_t NetworkId;              /* network id of adapter  */
	int      NetworkType;            /* adapter network type (llr_network_type) */
        int      ConfigStatus;           /* adapter config status (llr_adapter_state_t)*/
        int      ConnectionStatus;       /* adapter connection status (llr_adapter_state_t)*/
        int      HeartbeatStatus;        /* adapter heart beat status (llr_heartbeat_status_t)*/

	std::vector<Adapter*> managed_adapters;

private:
	bool _managed;

	int  _windows_in_use;
	int  _exclusive_use;
};


#endif
