/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <pthread.h>
#include <stdio.h>
#include "Thread.h"
#include "Mutex.h"
#include "AdapterReq.h"
#include <stdint.h>
#include "llrapi.h"
#include "rm_symbols.h"
#include "Scheduler.h"
#include "Log.h"

bool
AdapterReq::updateData(void* llr_adapter_req) {
	Scheduler&     s   = Scheduler::getInstance();
	llr_element_t* err = NULL;
	int            rc  = 0;

	GET_DATA(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqUsage, Usage, err);
	GET_DATA(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqCommLevel, CommLevel, err);
	GET_DATA(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqInstances, Instances, err);
	GET_DATA(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqRcxtBlks, RcxtBlks, err);
	GET_DATA_P(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqProtocol, Protocol, err);
	GET_DATA(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqMode, Mode, err);
	GET_DATA_P(rc, s.rm_handle, llr_adapter_req, LLR_AdapterReqTypeName, TypeName, err);

	display_adapter_req_data();
	return (rc == 0);
}

void
AdapterReq::display_adapter_req_data() {
	log(0, "ADAPTER_REQ Usage:     %d\n", Usage);
	log(0, "ADAPTER_REQ CommLevel: %d\n", CommLevel);
	log(0, "ADAPTER_REQ Instances: %d\n", Instances);
	log(0, "ADAPTER_REQ RcxtBlks:  %d\n", RcxtBlks);
	log(0, "ADAPTER_REQ Protocol:  %s\n", Protocol);
	log(0, "ADAPTER_REQ Mode:      %s\n", enum_to_string((llr_network_mode_t)Mode));
	log(0, "ADAPTER_REQ TypeName:  %s\n", TypeName);
}

AdapterReq::AdapterReq() {
	Usage     = 0;
	CommLevel = 0;
	Instances = 0;
	RcxtBlks  = 0;
	Protocol  = NULL;
	Mode      = LLR_IP_MODE;
	TypeName  = NULL;
}

AdapterReq::~AdapterReq() {
	FREE_IF_SET(Protocol);
	FREE_IF_SET(TypeName);
}




