/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <vector>
#include "Object.h"
#include "Mutex.h"
#include "Step.h"

#ifndef Job_h
#define Job_h

class Job : public Object {
public:
	Job(char* job_name);
	~Job();

	int comparePriority(const Job& job) const {
		if (_priority < job._priority) {
			return -1;
		} else if (_priority > job._priority) {
			return +1;
		} else {
			return 0;
		}
	}

	bool updateData(void* llr_job);
	void display_job_data();

	void clear_steps();

	Mutex lock;

	/* Job object data */
	char*      JobID;       /* job name                       */
	char*      JobName;     /* job name                       */
	//Credential Cred;        /* credentials                    */
	int        Mode;        /* INTERACTIVE_JOB or BATCH_JOB   */
	char*      SubmitHost;  /* host job was submitted from    */
	int        JobQueueKey; /* key used to write job to spool */
	char*      JobManager;  /* Schedd managing the job        */
	time_t     SubmitTime;  /* time job was queued            */
	int        VersionNum;  /* job version number             */
	int        StepCount;   /* number of steps in job         */

	std::vector<Step*> steps;

private:
	int _priority;
};


#endif
