/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdio.h>
#include <time.h>
#include <sys/time.h>
#include <stdarg.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <string>

#include <stdio.h>

#include "Mutex.h"
#include "Thread.h"
#include "Scheduler.h"

static char  log_buffer[1024*1024];
static Mutex log_lock;
static FILE* log_file = NULL;


void initialize_log() {
	char* scheduler_log = Scheduler::SCHEDULER_LOG;

	if (scheduler_log == NULL) {
		return;
	}

	log_file = fopen(scheduler_log, "a");

        if (log_file == NULL) {
                printf("Error opening file %s\n", scheduler_log);
                return;
        }
}

void close_log() {
	if (log_file != NULL) {
		fclose(log_file);
		log_file = NULL;
	}
}

void log(int level, ...) {
	if (level > Scheduler::DEBUG_LEVEL) {
		return;
	}

	va_list pvar;

	Thread* my_thread = Thread::currentThread();

	int my_tid = 0;

	if (my_thread) {
		my_tid = my_thread->TID();
	}

	struct timeval tod_value;
	gettimeofday(&tod_value, NULL);

	va_start(pvar, level);
	char* default_str;
	default_str = va_arg(pvar, char*);
	log_lock.lock();
	vsprintf(log_buffer, default_str, pvar);
	if (log_file != NULL) {
		fprintf(log_file, "%d.%06d TI-%d %s", tod_value.tv_sec, tod_value.tv_usec, my_tid, log_buffer);
		fflush(log_file);
	} else {
		printf("%d.%06d TI-%d %s", tod_value.tv_sec, tod_value.tv_usec, my_tid, log_buffer);
	}
	log_lock.unlock();
}

