/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdlib.h>
#include <vector>
#include "Object.h"
#include "Mutex.h"
#include <stdint.h>
#include "llrapi.h"

#ifndef Step_h
#define Step_h

class Job;
class Node;
class AdapterReq;
class Machine;

class Step : public Object {
public:
	Step(const char* step_name);
	~Step();

	int comparePriority(const Step& step) const;

	bool updateData(void* llr_step);
	void display_step_data();

	Mutex lock;
	int   _priority;

	Job* job() { return _job; }
	void job(Job* j) { _job = j; }

	void addMachine(Machine* machine);

	bool isRunningLike() {
		llr_step_state_t s = (llr_step_state_t)State;
		return ((s == LLR_STATE_COMPLETE_PENDING) ||
        	        (s == LLR_STATE_PENDING)          ||
        	        (s == LLR_STATE_PREEMPT_PENDING)  ||
        	        (s == LLR_STATE_REJECT_PENDING)   ||
        	        (s == LLR_STATE_REMOVE_PENDING)   ||
        	        (s == LLR_STATE_RESUME_PENDING)   ||
        	        (s == LLR_STATE_RUNNING)          ||
        	        (s == LLR_STATE_STARTING)         ||
        	        (s == LLR_STATE_VACATE_PENDING));
	}

	void clear_nodes();
	void clear_adapter_reqs();
	void clear_machines();

	std::vector<Node*>       nodes;
	std::vector<AdapterReq*> adapter_reqs;
	std::vector<Machine*>    machines;

	bool consumesResources() {
		return _consumes_resources;
	}

	void consumesResources(bool consumes_resources) {
		_consumes_resources = consumes_resources;
	}

        /* Step object data */
        char*   StepID;                 /* resource manager job step id */
        char*   StepName;               /* name assigned to step      */
        int     NodeCount;              /* number of nodes in step      */
        int     MachineCount;           /* number of machines assigned  */
        //LLR_StepGetFirstMachine;        /* LL_element * (LlMachine): first machine*/
        //LLR_StepGetNextMachine;         /* LL_element * (LlMachine): next machine */
        //LLR_StepGetMasterTask;          /* LL_element * (Task): master task on step */
        int     MachUsageCount;         /* count of machine usages */
        //LLR_StepGetFirstMachUsage;      /* LL_element * (MachineUsage): first machine usage */
        //LLR_StepGetNextMachUsage;       /* LL_element * (MachineUsage): next machine usage */
        char*   AccountNumber;          /* associated account number   */
        char*   Comment;                /* user defined comment       */
        int     CompletionCode;         /* exit status                  */
        time_t  CompletionDate;         /* UNIX time step was completed */
        char*   Environment;            /* environment                        */
        char*   ErrorFile;              /* name of error file                 */
        int     ExecSize;               /* size of the master executable */
        int     ImageSize;              /* size of the virtual image in K */
        int64_t ImageSize64;            /* size of the virtual image in K */
        char*   InputFile;              /* name of input file                 */
        char*   Iwd;                    /* initial directory          */
        char*   JobClass;               /* defined class for step     */
        int     NodeUsage;              /* requested node usage         */
        char*   OutputFile;             /* name of output file        */
        int     ParallelMode;           /* mode of the step             */
        char*   Shell;                  /* shell to be used           */
        int     StartCount;             /* times step has been started  */
        time_t  StartDate;              /* date step was started     */
        time_t  StartTime;              /* time the starter process for the job step started  */
        time_t  DispatchTime;           /* time step was started     */
        int     TaskInstanceCount;      /* number of task instances     */
        int     CpuLimitHard;           /* cpu hard limit               */
        int64_t CpuLimitHard64;         /* cpu hard limit           */
        int     CpuLimitSoft;           /* cpu soft limit               */
        int64_t CpuLimitSoft64;         /* cpu soft limit           */
        int     DataLimitHard;          /* data hard limit              */
        int64_t DataLimitHard64;        /* data hard limit  */
        int     DataLimitSoft;          /* data soft limit              */
        int64_t DataLimitSoft64;        /* data soft limit  */
        int64_t AsLimitHard64;          /* as hard limit         */
        int64_t AsLimitSoft64;          /* as soft limit         */
        int64_t NprocLimitHard64;       /* nproc hard limit      */
        int64_t NprocLimitSoft64;       /* nproc soft limit      */
        int64_t MemlockLimitHard64;     /* memlock hard limit    */
        int64_t MemlockLimitSoft64;     /* memlock soft limit    */
        int64_t LocksLimitHard64;       /* locks hard limit      */
        int64_t LocksLimitSoft64;       /* locks soft limit      */
        int64_t NofileLimitHard64;      /* nofile hard limit     */
        int64_t NofileLimitSoft64;      /* nofile soft limit     */
        int     CoreLimitSoft;          /* core file soft limit         */
        int64_t CoreLimitSoft64;        /* core file soft limit     */
        int     CoreLimitHard;          /* core file hard limit         */
        int64_t CoreLimitHard64;        /* core file hard limit     */
        int     FileLimitHard;          /* file size hard limit         */
        int64_t FileLimitHard64;        /* file size hard limit     */
        int     FileLimitSoft;          /* file size soft limit         */
        int64_t FileLimitSoft64;        /* file size soft limit     */
        int     RssLimitHard;           /* resident set size hard limit */
        int64_t RssLimitHard64;         /* resident set size hard limit */
        int     RssLimitSoft;           /* resident set size soft limit */
        int64_t RssLimitSoft64;         /* resident set size soft limit */
        int     StackLimitHard;         /* stack size hard limit        */
        int64_t StackLimitHard64;       /* stack size hard limit    */
        int     StackLimitSoft;         /* stack size soft limit        */
        int64_t StackLimitSoft64;       /* stack size soft limit    */
        int     CpuStepLimitHard;       /* cpu hard limit for entire job */
        int64_t CpuStepLimitHard64;     /* cpu hard limit for entire job */
        int     CpuStepLimitSoft;       /* cpu soft limit for entire job */
        int64_t CpuStepLimitSoft64;     /* cpu soft limit for entire job */
        int     WallClockLimitHard;     /* wall clock hard limit        */
        int64_t WallClockLimitHard64;   /* wall clock hard limit*/
        int     WallClockLimitSoft;     /* wall clock soft limit        */
        int64_t WallClockLimitSoft64;   /* wall clock soft limit*/
        int     State;                  /* current state of the step    */
        char**  HostList;               /* hosts in host.list file */
        char*   LoadLevelerGroup;       /* LL group specified by step  */
        char*   TaskGeometry;           /* task geometry requested */
        char*   TotalNodesRequested;    /* total nodes requested */
        int     Restart;                /* restartable job? */
        int     TotalTasksRequested;    /* total tasks requested */
        int     TasksPerNodeRequested;  /* tasks per node requested */
        int     Blocking;               /* blocking factor requested */
        int64_t StepUserTime64;         /* step user time - microseconds */
        int64_t StepSystemTime64;       /* step system time - microseconds */
        int64_t StepMaxrss64;           /* step ru_maxrss */
        int64_t StepIxrss64;            /* step ru_ixrss */
        int64_t StepIdrss64;            /* step ru_idrss */
        int64_t StepIsrss64;            /* step ru_isrss */
        int64_t StepMinflt64;           /* step ru_minflt */
        int64_t StepMajflt64;           /* step ru_majflt */
        int64_t StepNswap64;            /* step ru_nswap */
        int64_t StepInblock64;          /* step ru_inblock */
        int64_t StepOublock64;          /* step ru_oublock */
        int64_t StepMsgsnd64;           /* step ru_msgsnd */
        int64_t StepMsgrcv64;           /* step ru_msgrcv */
        int64_t StepNsignals64;         /* step ru_nsignals */
        int64_t StepNvcsw64;            /* step ru_nvcsw */
        int64_t StepNivcsw64;           /* step ru_nivcsw */
        int64_t StarterUserTime64;      /* starter user time-microseconds */
        int64_t StarterSystemTime64;    /* starter system time-microseconds */
        int64_t StarterMaxrss64;        /* starter ru_maxrss */
        int64_t StarterIxrss64;         /* starter ru_ixrss */
        int64_t StarterIdrss64;         /* starter ru_idrss */
        int64_t StarterIsrss64;         /* starter ru_isrss */
        int64_t StarterMinflt64;        /* starter ru_minflt */
        int64_t StarterMajflt64;        /* starter ru_majflt */
        int64_t StarterNswap64;         /* starter ru_nswap */
        int64_t StarterInblock64;       /* starter ru_inblock */
        int64_t StarterOublock64;       /* starter ru_oublock */
        int64_t StarterMsgsnd64;        /* starter ru_msgsnd */
        int64_t StarterMsgrcv64;        /* starter ru_msgrcv */
        int64_t StarterNsignals64;      /* starter ru_nsignals */
        int64_t StarterNvcsw64;         /* starter ru_nvcsw */
        int64_t StarterNivcsw64;        /* starter ru_nivcsw */
        int     Checkpointable;         /* 0-job not checkpointable */
        bool    Checkpointing;          /* step is being checkpointed */
        int     CkptAccumTime;          /* accumulated ckpt time */
        time_t  CkptFailStartTime;      /* time of last failed ckpt*/
        char*   CkptFile;               /* name of ckpt file */
        char*   CkptSubDir;             /* name of ckpt_subdir file */
        time_t  CkptGoodElapseTime;     /* time taken to complete last good ckpt */
        time_t  CkptGoodStartTime;      /* time of last good ckpt */
        int     CkptTimeHardLimit;      /* ckpt time hard limit */
        int64_t CkptTimeHardLimit64;    /* ckpt time hard limit */
        int     CkptTimeSoftLimit;      /* ckpt time soft limit */
        int64_t CkptTimeSoftLimit64;    /* ckpt time soft limit */
        int     CkptRestart;            /* 0|1 job restarted from ckpt*/
        int     CkptRestartSameNodes;   /* 0|1 restart job on same nodes */
        int     WallClockUsed;          /* wallclock already used by the step */
        char*   LargePage;              /* Large Page requirement (= "M", "Y", or "N") */
        int     MaxProtocolInstances;   /* largest number of instances allowed on network stmt */
        int     BulkXfer;               /* 0|1 Step Requests Bulk Transfer */
        int     TotalRcxtBlocks;        /* total number of RCXT blocks application needs */
        int     UserRcxtBlocks;         /* number of user RCXT blocks application requests */
        int     Preemptable;            /* 0|1 step is preemptable */
        char*   RsetName;               /* rset name */
        char*   McmAffinityOptions;     /* mcm affinity options */
        char    TaskAffinity;           /* task affinity request    */
        int     CpusPerCore;            /* cpus per core             */
        char*   CkptExecuteDirectory;   /* Executable directory for a checkpointable step */
        char*   MasterVirtualIP;        /* MetaCluster virtual IP associated with POE process */
        char*   MasterRealIP;           /* MetaCluster: real IP of adapter associated with POE process */
        char*   MasterNetmask;          /* MetaCluster: real netmask of adapter associated with POE process */
        char*   VipNetmask;             /* MetaCluster vipserver virtual netmask */
        char*   MetaClusterPoeHostname; /* MetaCluster:  POE host name */
        int     MetaClusterJobID;       /* MetaCluster job ID LoadLeveler has assigned to job step */
        int64_t AcctKey;                /* accounting key for step */
        char*   Dependency;             /* Step Dependency */
        char*   BgJobId;                /* Blue Gene ID for the step */
        int     BgJobState;             /* Blue Gene state for the step */
        int     BgConnectionRequested;  /* type of wiring requested for Blue Gene step */
        char*   BgPartitionAllocated;   /* Blue Gene partition allocated for step */
        char*   BgErrorText;            /* error text from Blue Gene system for step */
        int     BgSizeRequested;        /* size requested for Blue Gene step */
        int*    BgShapeRequested;       /* shape requested for Blue Gene step */
        int     BgPartitionType;        /* Blue Gene partition type */
        int     Coschedule;             /* 0|1 coschedule option */
        int     SMTRequired;            /* if SMT is required to be turned on , off or as_is for step */

private:
	Job* _job;
	bool _consumes_resources;
};


#endif
